@@ -27,9 +27,11 @@ class AFPEntitiesParameters(ProcessorParameters):
     <li>**unknown** to retain all but prepending the `unknown_prefix` to the label of unknown entities<br />""",
     )
     kill_label: Optional[str] = Field("kill", description="Label name of the kill list")
+    white_label: Optional[str] = Field("white", description="Label name of the white list")
     eurovoc_label: Optional[str] = Field(
         "eurovoc", description="Label name of the Eurovoc thesaurus"
     )
+    wikidata_label: Optional[str] = Field("wikidata", description="Label name of Wikidata entities")
     as_altText: str = Field(
         "fingerprint",
         description="""If defined generate the fingerprint as an alternative text of the input document.""",
@@ -46,7 +48,7 @@ class AFPEntitiesProcessor(ProcessorBase):
         for document in documents:
             with add_logging_context(docid=document.identifier):
                 if document.annotations:
-                    mark_whitelisted(document)
+                    mark_whitelisted(document, params.white_label)
                     ann_groups = group_annotations(document, by_lexicon)
                     # 1. Compute document fingerprint
                     fingerprints = compute_fingerprint(ann_groups)
@@ -62,7 +64,8 @@ class AFPEntitiesProcessor(ProcessorBase):
                         )
                         document.altTexts = altTexts
                     # 2. Consolidate & links against KB and Wikidata
-                    conso_anns = consolidate_and_link(ann_groups, params.kill_label)
+                    conso_anns = consolidate_and_link(ann_groups, params.kill_label, params.white_label,
+                                                      params.wikidata_label, params.eurovoc_label)
                     document.annotations = conso_anns
         return documents
 
@@ -111,31 +114,27 @@ def compute_fingerprint(ann_groups):
     return fingerprints
 
 
-def mark_whitelisted(document):
+def mark_whitelisted(document, white_label):
     for a in document.annotations:
-        if is_whitelist(
-            a
-        ):  # Consider whitelisted terms as entities coming from the model
-            if a.label.startswith("AFP"):
-                a.label = a.label[3:]
-                a.labelName = a.labelName[3:]
-                a.terms = None
+        if a.labelName == white_label:  # Consider whitelisted terms as entities coming from the model
+            a.terms = None
 
 
-def consolidate_and_link(ann_groups, kill_label):
+def consolidate_and_link(ann_groups, kill_label, white_label, wikidata_label, eurovoc_label):
     conso_anns = []
+    kb_names = [item for item in ann_groups.keys() if item not in ["", kill_label, white_label, wikidata_label, eurovoc_label]]
     for model_r in ann_groups[""].ranges():
         model_ann = model_r.value
         gname = model_ann.labelName
 
-        kill_r = annotation_in_group(model_ann, ann_groups, kill_label)
+        kill_r = annotation_in_group(model_ann, ann_groups, [kill_label])
         perfect, kill_match = one_match(model_ann, kill_r)
         if perfect and kill_match:
             logger.warning("Kill annotation")
             logger.warning(f"=> {model_ann}")
             continue
 
-        kb_r = annotation_in_group(model_ann, ann_groups)
+        kb_r = annotation_in_group(model_ann, ann_groups, kb_names)
         perfect, kb_match = one_match(model_ann, kb_r)
         if kb_match:
             if perfect:
@@ -155,7 +154,7 @@ def consolidate_and_link(ann_groups, kill_label):
             for r in kb_r.values():
                 logger.warning(f" -{r}")
 
-        wiki_r = annotation_in_group(model_ann, ann_groups, "wikidata")
+        wiki_r = annotation_in_group(model_ann, ann_groups, [wikidata_label])
         perfect, wiki_match = one_match(model_ann, wiki_r)
         if wiki_match:
             if validate_wiki_type(wiki_match, gname):
@@ -227,15 +226,16 @@ def one_match(a: Annotation, matches: RangeMap):
 
 # noqa: W503
 def annotation_in_group(
-    a: Annotation, ann_groups: Dict[str, RangeMap], gname: str = None
+    a: Annotation, ann_groups: Dict[str, RangeMap], gnames: List[str] = None
 ):
-    gname = gname or a.labelName
-    if (
-        gname in ann_groups
-        and a.start in ann_groups[gname]
-        or a.end in ann_groups[gname]
-    ):
-        return ann_groups[gname][a.start : a.end]
+    gnames = gnames or [a.labelName]
+    for gname in gnames:
+        if (
+            gname in ann_groups
+            and a.start in ann_groups[gname]
+            or a.end in ann_groups[gname]
+        ):
+            return ann_groups[gname][a.start : a.end]
     return None
 
 
